messagingapp/msgui/unifiededitor/inc/msgunieditoraddress.h
changeset 25 84d9eb65b26f
parent 23 238255e8b033
child 27 e4592d119491
child 37 518b245aa84c
--- a/messagingapp/msgui/unifiededitor/inc/msgunieditoraddress.h	Fri Apr 16 14:56:15 2010 +0300
+++ b/messagingapp/msgui/unifiededitor/inc/msgunieditoraddress.h	Mon May 03 12:29:07 2010 +0300
@@ -27,7 +27,6 @@
 class HbPushButton;
 class HbLineEdit;
 class MsgUnifiedEditorLineEdit;
-class MsgUiUtilsManager;
 
 class MsgUnifiedEditorAddress : public HbWidget
     {
@@ -62,6 +61,11 @@
      * setter method to set address
      */
     void setAddresses(ConvergedMessageAddressList addrlist);
+    
+    /**
+     * Get amount of digits to be used in contact matching
+     */
+    static int contactMatchDigits();
         
 signals:
     /**
@@ -70,27 +74,36 @@
     void sendMessage();
 
     /**
-     * Emitted when MMS content is added or removed
+     * Emitted when content is added or removed
      */
-    void mmContentAdded(bool isAdded);
+    void contentChanged();
 
 private slots:
    
     /**
      * called after selection from pbk.
      */
-    void contactsFetched(const QVariant& contacts);
+    void fetchContacts();
+    /**
+     * Slot for handling valid returns from the phonebook contacts fetched.
+     */
+    void handleOk(const QVariant& result);
+    
+    /**
+     * Slot for handling errors. Error ids are provided as 
+     */
+    void handleError(int errorCode, const QString& errorMessage);
 
     /**
      * Called when textChanged signal is emitted by the line edit
      */
-    void onTextChanged(const QString&);
+    void onContentsAdded(const QString&);
 
     /**
      * Called when textChanged signal is emitted by the line edit
      * Checks for empty text content
      */
-    void onTextRemoved(const QString& text);
+    void onContentsRemoved(const QString& text);
 
 private:
     /**
@@ -128,12 +141,7 @@
      * address map.
      */
     QMap<QString, QString> mAddressMap;
-
-    /**
-     * MsgUiUtils Manager for phonebook operations
-     * Not Owned
-     */
-    MsgUiUtilsManager *mUtilsManager;
+   
     };
 
 #endif //UNIFIED_EDITOR_ADDRESS_H
@@ -70,27 +74,36 @@
 
     /**
-     * Called when textChanged signal is emitted by the line edit
+     * Called when contentsChanged signal is emitted by the line edit
      */
@@ -70,27 +74,36 @@
 
     /**
-     * Called when textChanged signal is emitted by the line edit
+     * Called when contentsChanged signal is emitted by the line edit
      * Checks for empty text content
      */